@@ -12,7 +12,7 @@ This work can be distributed under the terms of the GNU GPLv3.
 '''
 
 import argparse
-import atexit
+import contextlib
 import os
 import shutil
 import subprocess
@@ -34,7 +34,6 @@ from s3ql.logging import logging, setup_logging, QuietError
 from s3ql.common import get_backend
 from s3ql.backends.common import DanglingStorageURLError
 from s3ql.backends.comprenc import ComprencBackend
-from s3ql.backends.local import Backend
 from s3ql import BUFSIZE
 from s3ql.parse_args import ArgumentParser
 
@@ -50,6 +49,7 @@ def parse_args(args):
                             'compression speed and determine limiting factor.')
 
     parser.add_quiet()
+    parser.add_log()
     parser.add_debug()
     parser.add_backend_options()
     parser.add_version()
@@ -63,6 +63,58 @@ def parse_args(args):
     return parser.parse_args(args)
 
 
+def test_write_speed(size, blocksize, cachedir, rnd_fh):
+
+    with contextlib.ExitStack() as mgr:
+        mnt_dir = tempfile.mkdtemp(prefix='s3ql-mnt')
+        mgr.callback(shutil.rmtree, mnt_dir)
+
+        backend_dir = tempfile.mkdtemp(prefix='s3ql-benchmark-')
+        mgr.callback(shutil.rmtree, backend_dir)
+
+        subprocess.check_call([exec_prefix + 'mkfs.s3ql', '--plain', 'local://%s' % backend_dir,
+                               '--quiet', '--cachedir', cachedir])
+        subprocess.check_call([exec_prefix + 'mount.s3ql', '--threads', '1', '--quiet',
+                               '--cachesize', '%d' % (2 * size / 1024), '--log',
+                               '%s/mount.log' % backend_dir, '--cachedir', cachedir,
+                               'local://%s' % backend_dir, mnt_dir])
+        try:
+            write_time = 0
+            while write_time < 3:
+                log.debug('Write took %.3g seconds, retrying', write_time)
+                size *= 2
+                with open('%s/bigfile' % mnt_dir, 'wb', 0) as dst:
+                    rnd_fh.seek(0)
+                    write_time = time.time()
+                    copied = 0
+                    while copied < size:
+                        buf = rnd_fh.read(blocksize)
+                        if not buf:
+                            rnd_fh.seek(0)
+                            continue
+                        dst.write(buf)
+                        copied += len(buf)
+                write_time = time.time() - write_time
+                os.unlink('%s/bigfile' % mnt_dir)
+        finally:
+            subprocess.check_call([exec_prefix + 'umount.s3ql', mnt_dir])
+
+    return copied / write_time
+
+
+class MockBackend:
+    def open_write(key, metadata=None, is_compressed=False):
+        return MockFH()
+
+
+class MockFH:
+    def write(self, buf):
+        pass
+
+    def close(self):
+        pass
+
+
 def main(args=None):
     if args is None:
         args = sys.argv[1:]
@@ -81,43 +133,10 @@ def main(args=None):
             copied += len(buf)
 
     log.info('Measuring throughput to cache...')
-    backend_dir = tempfile.mkdtemp(prefix='s3ql-benchmark-')
-    mnt_dir = tempfile.mkdtemp(prefix='s3ql-mnt')
-    atexit.register(shutil.rmtree, backend_dir)
-    atexit.register(shutil.rmtree, mnt_dir)
-
     block_sizes = [ 2**b for b in range(12, 18) ]
     for blocksize in block_sizes:
-        write_time = 0
         size = 50 * 1024 * 1024
-        while write_time < 3:
-            log.debug('Write took %.3g seconds, retrying', write_time)
-            subprocess.check_call([exec_prefix + 'mkfs.s3ql', '--plain', 'local://%s' % backend_dir,
-                                   '--quiet', '--force', '--cachedir', options.cachedir])
-            subprocess.check_call([exec_prefix + 'mount.s3ql', '--threads', '1', '--quiet',
-                                   '--cachesize', '%d' % (2 * size / 1024), '--log',
-                                   '%s/mount.log' % backend_dir, '--cachedir', options.cachedir,
-                                   'local://%s' % backend_dir, mnt_dir])
-            try:
-                size *= 2
-                with open('%s/bigfile' % mnt_dir, 'wb', 0) as dst:
-                    rnd_fh.seek(0)
-                    write_time = time.time()
-                    copied = 0
-                    while copied < size:
-                        buf = rnd_fh.read(blocksize)
-                        if not buf:
-                            rnd_fh.seek(0)
-                            continue
-                        dst.write(buf)
-                        copied += len(buf)
-
-                write_time = time.time() - write_time
-                os.unlink('%s/bigfile' % mnt_dir)
-            finally:
-                subprocess.check_call([exec_prefix + 'umount.s3ql', mnt_dir])
-
-        fuse_speed = copied / write_time
+        fuse_speed = test_write_speed(size, blocksize, options.cachedir, rnd_fh)
         log.info('Cache throughput with %3d KiB blocks: %d KiB/sec',
                  blocksize / 1024, fuse_speed / 1024)
 
@@ -159,7 +178,7 @@ def main(args=None):
     out_speed = dict()
     for alg in ALGS:
         log.info('compressing with %s-6...', alg)
-        backend = ComprencBackend(b'pass', (alg, 6),Backend(argparse.Namespace(storage_url='local://' + backend_dir)))
+        backend = ComprencBackend(b'pass', (alg, 6), MockBackend())
         def do_write(dst): #pylint: disable=E0102
             src.seek(0)
             stamp = time.time()
@@ -188,7 +207,7 @@ def main(args=None):
         threads.add(options.threads)
 
     print('%-26s' % 'Threads:',
-          ('%12d' * len(threads)) % tuple(sorted(threads)))
+          ('%16d' * len(threads)) % tuple(sorted(threads)))
 
     for alg in ALGS:
         speeds = []
@@ -209,9 +228,9 @@ def main(args=None):
             speeds.append(speed / 1024)
 
         print('%-26s' % ('Max FS throughput (%s):' % alg),
-              ('%7d KiB/s' * len(threads)) % tuple(speeds))
+              ('%10d KiB/s' * len(threads)) % tuple(speeds))
         print('%-26s' % '..limited by:',
-              ('%12s' * len(threads)) % tuple(limits))
+              ('%16s' * len(threads)) % tuple(limits))
 
     print('')
     print('All numbers assume that the test file is representative and that',
